@@ -1,5 +1,8 @@
 #' Frequency polygon.
 #'
+#' @section Aesthetics: 
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "freqpoly")}
+#'
 #' @seealso \code{\link{geom_histogram}}: histograms
 #' @inheritParams geom_point
 #' @export
@@ -19,11 +22,6 @@ geom_freqpoly <- function (mapping = NULL, data = NULL, stat = "bin", position =
 
 GeomFreqpoly <- proto(Geom, {
   objname <- "freqpoly"
-
-  icon <- function(.) {
-    y <- c(0.2, 0.3, 0.5, 0.6,0.2, 0.8, 0.5, 0.3)
-    linesGrob(seq(0.1, 0.9, by=0.1), y, gp=gpar(col="grey20"))
-  }
   
   default_aes <- function(.) GeomPath$default_aes()
   default_stat <- function(.) StatBin
