@@ -1,5 +1,8 @@
 #' Single line segments.
 #'
+#' @section Aesthetics: 
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "segment")}
+#'
 #' @inheritParams geom_point
 #' @param arrow specification for arrow heads, as created by arrow()
 #' @seealso \code{\link{geom_path}} and \code{\link{geom_line}} for multi-
@@ -48,8 +51,8 @@ GeomSegment <- proto(Geom, {
     if (is.linear(coordinates)) {
       return(with(coord_transform(coordinates, data, scales), 
         segmentsGrob(x, y, xend, yend, default.units="native",
-        gp = gpar(col=alpha(colour, alpha), lwd=size * .pt, 
-          lty=linetype, lineend = "butt"), 
+        gp = gpar(col=alpha(colour, alpha), fill = alpha(colour, alpha),
+          lwd=size * .pt, lty=linetype, lineend = "butt"), 
         arrow = arrow)
       ))
     }
@@ -65,9 +68,6 @@ GeomSegment <- proto(Geom, {
   }
 
   
-  icon <- function(.) segmentsGrob(c(0.1, 0.3, 0.5, 0.7), c(0.3, 0.5, 0.1, 0.9), c(0.2, 0.5, 0.7, 0.9), c(0.8, 0.7, 0.4, 0.3))
-
-
   default_stat <- function(.) StatIdentity
   required_aes <- c("x", "y", "xend", "yend")
   default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = NA)
